@@ -12,9 +12,9 @@
 
 
 __pkgname__   = 'cmdkit'
-__version__   = '2.0.2'
+__version__   = '2.1.0'
 __authors__   = 'Geoffrey Lentner'
-__contact__   = '<glentner@gmail.com>'
+__contact__   = 'glentner@purdue.edu'
 __license__   = 'Apache License'
 __copyright__ = 'Copyright (c) Geoffrey Lentner 2019. All Rights Reserved.'
-__description__ = 'A command-line utility toolkit.'
+__description__ = 'A command-line utility toolkit for Python.'
